@@ -43,6 +43,7 @@
 
 #include  "Helpers.h"
 #include  "ColumnResizer.h"
+#include  "Widgets.h"
 
 
 #include  "fstream_unicode.h"
@@ -99,20 +100,32 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::getInfo");
             album(m_nCrtAlbum).copyTo(*pAlbumInfo);
             //pAlbumInfo->m_strReleased = convStr(m_pRealeasedE->text()); //ttt2 maybe allow users to overwrite fields in edit boxes, esp. genre; however, most of the cases it's almost as easy to make any changes in the tag editor (well, there's an F2 and then "copy form first"); there are several issues in implementing this: 1) going to prev/next album; 2) artist name gets copied to each track; 3) consistency: if the edit boxes are editable why not the table? so, better without
 
-            if (m_pVolumeCbB->isEnabled() && m_pVolumeCbB->currentIndex() != m_pVolumeCbB->count() - 1)
+            if (m_pVolumeCbB->isEnabled())
             {
-                vector<TrackInfo> vTracks;
-                string s (convStr(m_pVolumeCbB->itemText(m_pVolumeCbB->currentIndex())));
-                int k (cSize(s));
-                for (int i = 0, n = cSize(pAlbumInfo->m_vTracks); i < n; ++i)
-                {
-                    if (beginsWith(pAlbumInfo->m_vTracks[i].m_strPos, s))
+                if (m_pVolumeCbB->currentIndex() == m_pVolumeCbB->count() - 1)
+                { // just give sequential numbers when "<All>" in a multivolume is used - see https://sourceforge.net/projects/mp3diags/forums/forum/947206/topic/4503061/index/page/1 - perhaps can be improved
+                    char a [10];
+                    for (int i = 0; i < cSize(pAlbumInfo->m_vTracks); ++i)
                     {
-                        vTracks.push_back(pAlbumInfo->m_vTracks[i]);
-                        vTracks.back().m_strPos.erase(0, k);
+                        sprintf(a, "%02d", i + 1);
+                        pAlbumInfo->m_vTracks[i].m_strPos = a;
                     }
                 }
-                vTracks.swap(pAlbumInfo->m_vTracks);
+                else
+                {
+                    vector<TrackInfo> vTracks;
+                    string s (convStr(m_pVolumeCbB->itemText(m_pVolumeCbB->currentIndex())));
+                    int k (cSize(s));
+                    for (int i = 0, n = cSize(pAlbumInfo->m_vTracks); i < n; ++i)
+                    {
+                        if (beginsWith(pAlbumInfo->m_vTracks[i].m_strPos, s))
+                        {
+                            vTracks.push_back(pAlbumInfo->m_vTracks[i]);
+                            vTracks.back().m_strPos.erase(0, k);
+                        }
+                    }
+                    vTracks.swap(pAlbumInfo->m_vTracks);
+                }
             }
         }
 
@@ -151,7 +164,7 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::replaceSymbols");
     return s;
 }
 
-/*static*/ const char* AlbumInfoDownloaderDlgImpl::NOT_FOUND_AT_AMAZON = "not found at amazon.com";
+/*static*/ const char* AlbumInfoDownloaderDlgImpl::NOT_FOUND_AT_AMAZON = QT_TRANSLATE_NOOP("AlbumInfoDownloaderDlgImpl", "not found at amazon.com");
 
 void AlbumInfoDownloaderDlgImpl::search()
 {
@@ -168,7 +181,7 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::search");
     m_pImageL->setPixmap(0);
     m_pImageL->setText("");
     m_pImgSizeL->setText("\n");
-    m_pViewAtAmazonL->setText(NOT_FOUND_AT_AMAZON);
+    m_pViewAtAmazonL->setText(tr(NOT_FOUND_AT_AMAZON));
 
     m_strQuery = escapeHttp(createQuery()); // e.g. http://www.discogs.com/search?type=all&q=beatles&f=xml&api_key=f51e9c8f6c, without page number; to be used by loadNextPage();
     m_nTotalPages = 1; m_nLastLoadedPage = -1;
@@ -177,7 +190,7 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::search");
     //m_eNavigDir = NEXT;
     m_eNavigDir = NEXT;
     m_bNavigateByAlbum = false;
-    addNote("searching ...");
+    addNote(tr("searching ..."));
     m_pGenreE->setText("");
     //next(); //loadNextPage();
     retryNavigation();
@@ -233,13 +246,13 @@ void AlbumInfoDownloaderDlgImpl::on_m_pSaveAllB_clicked()
 LAST_STEP("AlbumInfoDownloaderDlgImpl::on_m_pSaveAllB_clicked");
     if (NOTHING != m_eWaiting)
     {
-        QMessageBox::critical(this, "Error", "You cannot save the results now, because a request is still pending");
+        showCritical(this, tr("Error"), tr("You cannot save the results now, because a request is still pending"));
         return;
     }
 
     if (0 == getAlbumCount())
     {
-        QMessageBox::critical(this, "Error", "You cannot save the results now, because no album is loaded");
+        showCritical(this, tr("Error"), tr("You cannot save the results now, because no album is loaded"));
         return;
     }
 
@@ -265,24 +278,24 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::on_m_pSaveAllB_clicked");
     if (nCnt != m_nExpectedTracks)
     {
         QString s;
-        const char* szVolMsg (
+        const QString& qstrVolMsg (
             m_pVolumeCbB->isEnabled() &&
             (
                 (nCnt > m_nExpectedTracks && m_pVolumeCbB->currentIndex() == m_pVolumeCbB->count() - 1) ||
                 (nCnt < m_nExpectedTracks && m_pVolumeCbB->currentIndex() != m_pVolumeCbB->count() - 1)
             )
-            ? "You may want to use a different volume selection on this multi-volume release.\n\n" : "");
+            ? tr("You may want to use a different volume selection on this multi-volume release.\n\n") : "");
 
         if (nCnt > m_nExpectedTracks)
         {
-            s = QString("A number of %1 tracks were expected, but your selection contains %2. Additional tracks will be discarded.\n\n%3Save anyway?").arg(m_nExpectedTracks).arg(nCnt).arg(szVolMsg);
+            s = tr("A number of %1 tracks were expected, but your selection contains %2. Additional tracks will be discarded.\n\n%3Save anyway?").arg(m_nExpectedTracks).arg(nCnt).arg(qstrVolMsg);
         }
         else
         {
-            s = QString("A number of %1 tracks were expected, but your selection only contains %2. Remaining tracks will get null values.\n\n%3Save anyway?").arg(m_nExpectedTracks).arg(nCnt).arg(szVolMsg);
+            s = tr("A number of %1 tracks were expected, but your selection only contains %2. Remaining tracks will get null values.\n\n%3Save anyway?").arg(m_nExpectedTracks).arg(nCnt).arg(qstrVolMsg);
         }
-        QMessageBox::StandardButton eRes (QMessageBox::question(this, "Count inconsistency", s, QMessageBox::Cancel | QMessageBox::Save));
-        if (QMessageBox::Save != eRes) { return; }
+
+        if (showMessage(this, QMessageBox::Question, 1, 1, tr("Count inconsistency"), s, tr("&Save"), tr("Cancel")) != 0) { return; }
     }
 
     m_bSaveImageOnly = false;
@@ -294,13 +307,13 @@ void AlbumInfoDownloaderDlgImpl::on_m_pSaveImageB_clicked()
 LAST_STEP("AlbumInfoDownloaderDlgImpl::on_m_pSaveImageB_clicked");
     if (NOTHING != m_eWaiting)
     {
-        QMessageBox::critical(this, "Error", "You cannot save the results now, because a request is still pending");
+        showCritical(this, tr("Error"), tr("You cannot save the results now, because a request is still pending"));
         return;
     }
 
     if (0 == getAlbumCount() || -1 == m_nCrtImage)
     {
-        QMessageBox::critical(this, "Error", "You cannot save any image now, because there is no image loaded");
+        showCritical(this, tr("Error"), tr("You cannot save any image now, because there is no image loaded"));
         return;
     }
     // ttt2 perhaps shouldn't save an "error" image
@@ -493,7 +506,7 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::onRequestFinished");
 //if (1 == nId) { return; } // some automatically generated request, which should be ignored
     if (bError)
     {
-        addNote("request error");
+        addNote(tr("request error"));
         resetNavigation();
         return;
     }
@@ -512,7 +525,7 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::onRequestFinished");
 
     CB_ASSERT (NOTHING != m_eWaiting);
 
-    { QString qstrMsg (QString("received %1 bytes").arg(nAv)); addNote(qstrMsg.toLatin1().constData()); }
+    { QString qstrMsg (tr("received %1 bytes").arg(nAv)); addNote(qstrMsg); }
 
     QString qstrXml;
 
@@ -521,7 +534,7 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::onRequestFinished");
 
     if (nAv < 10)
     { // too short
-        addNote("received very short response; aborting request ...");
+        addNote(tr("received very short response; aborting request ..."));
         resetNavigation();
         return;
     }
@@ -535,7 +548,7 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::onRequestFinished");
 
         if (img.loadFromData(b)) //ttt2 not sure what happens for huge images;
         {
-            qstrInfo = QString("Original: %1kB, %2x%3").arg(nAv/1024).arg(img.width()).arg(img.height());
+            qstrInfo = tr("Original: %1kB, %2x%3").arg(nAv/1024).arg(img.width()).arg(img.height());
             //cout << "image size " << img.width() << "x" << img.height() << endl;
 
             int nWidth (img.width()), nHeight (img.height());
@@ -548,24 +561,24 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::onRequestFinished");
                 m_eLoadingImageCompr = ImageInfo::JPG;
 
                 //cout << "scaled image size " << img.width() << "x" << img.height() << endl;
-                qstrInfo += QString("\nRecompressed to: %1kB, %2x%3").arg(comprImg.size()/1024).arg(img.width()).arg(img.height());
+                qstrInfo += tr("\nRecompressed to: %1kB, %2x%3").arg(comprImg.size()/1024).arg(img.width()).arg(img.height());
             }
             else
             {
-                qstrInfo += "\nNot recompressed";
+                qstrInfo += tr("\nNot recompressed");
             }
             onImageLoaded(comprImg, nWidth, nHeight, qstrInfo);
         }
         else
         {
-            QMessageBox::critical(this, "Error", "Failed to load the image");
+            showCritical(this, tr("Error"), tr("Failed to load the image"));
             const int SIZE (150);
             QImage errImg (SIZE, SIZE, QImage::Format_ARGB32);
             QPainter pntr (&errImg);
             pntr.fillRect(0, 0, SIZE, SIZE, QColor(255, 128, 128));
             pntr.drawRect(0, 0, SIZE - 1, SIZE - 1);
-            pntr.drawText(QRectF(0, 0, SIZE, SIZE), Qt::AlignCenter, "Error");
-            qstrInfo = "Error loading image\n";
+            pntr.drawText(QRectF(0, 0, SIZE, SIZE), Qt::AlignCenter, tr("Error"));
+            qstrInfo = tr("Error loading image\n");
             comprImg.clear();
             QBuffer bfr (&comprImg);
             errImg.save(&bfr, "png");
@@ -591,7 +604,7 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::onRequestFinished");
 
         //int nRes (inflateInit(&strm));
         int nRes (inflateInit2(&strm, 16 + 15)); // !!! see libz.h for details; "32" makes this able to handle both gzip and zlib, by auto-detecting the format; 16 is used to force gzip
-        if (Z_OK != nRes) { addNote("init error"); goto e2; }
+        if (Z_OK != nRes) { addNote(tr("init error")); goto e2; }
 
         strm.next_out = reinterpret_cast<unsigned char*>(&v[0]);
         strm.avail_out = v.size();
@@ -610,7 +623,7 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::onRequestFinished");
                 continue;
             }
 
-            addNote("unexpected result"); goto e2;
+            addNote(tr("unexpected result")); goto e2;
         }
 
         {
@@ -630,7 +643,7 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::onRequestFinished");
 
     if (qstrXml.isEmpty())
     {
-        addNote("empty string received");
+        addNote(tr("empty string received"));
     }
     else
     {
@@ -718,7 +731,7 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::retryNavigation");
 void AlbumInfoDownloaderDlgImpl::onSearchLoaded(const QString& qstrXml)
 {
 LAST_STEP("AlbumInfoDownloaderDlgImpl::onSearchLoaded");
-    addNote("search results received");
+    addNote(tr("search results received"));
     QByteArray b (qstrXml.toLatin1());
     QBuffer bfr (&b);
     //SearchXmlHandler hndl (*this);
@@ -731,7 +744,7 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::onSearchLoaded");
     QXmlInputSource src (&bfr);
     if (!rdr.parse(src))
     {
-        QMessageBox::critical(this, "Error", "Couldn't process the search result. (Usually this means that the server is busy, so trying later might work.)");
+        showCritical(this, tr("Error"), tr("Couldn't process the search result. (Usually this means that the server is busy, so trying later might work.)"));
         if (0 == getAlbumCount())
         {
             m_nTotalPages = 0;
@@ -743,7 +756,7 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::onSearchLoaded");
 
     if (0 == getAlbumCount() && m_nLastLoadedPage == m_nTotalPages - 1)
     {
-        QMessageBox::critical(this, "Error", "No results found");
+        showCritical(this, tr("Error"), tr("No results found"));
     }
 
     retryNavigation();
@@ -753,7 +766,7 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::onSearchLoaded");
 void AlbumInfoDownloaderDlgImpl::onAlbumLoaded(const QString& qstrXml)
 {
 LAST_STEP("AlbumInfoDownloaderDlgImpl::onAlbumLoaded");
-    addNote("album info received");
+    addNote(tr("album info received"));
     QByteArray b (qstrXml.toLatin1());
     QBuffer bfr (&b);
     //AlbumXmlHandler hndl (album(m_nLoadingAlbum));
@@ -767,7 +780,7 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::onAlbumLoaded");
     if (!rdr.parse(src))
     {
         //CB_ASSERT (false);
-        QMessageBox::critical(this, "Error", "Couldn't process the album information. (Usually this means that the server is busy, so trying later might work.)");
+        showCritical(this, tr("Error"), tr("Couldn't process the album information. (Usually this means that the server is busy, so trying later might work.)"));
         /*if (0 == getAlbumCount())
         {
             m_nTotalPages = 0;
@@ -785,7 +798,7 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::onAlbumLoaded");
 void AlbumInfoDownloaderDlgImpl::onImageLoaded(const QByteArray& comprImg, int nWidth, int nHeight, const QString& qstrInfo)
 {
 LAST_STEP("AlbumInfoDownloaderDlgImpl::onImageLoaded");
-    addNote("image received");
+    addNote(tr("image received"));
     CB_ASSERT (0 == album(m_nLoadingAlbum).m_vpImages[m_nLoadingImage]);
     CB_ASSERT (ImageInfo::INVALID != m_eLoadingImageCompr);
     album(m_nLoadingAlbum).m_vpImages[m_nLoadingImage] = new ImageInfo(-1, ImageInfo::OK, m_eLoadingImageCompr, comprImg, nWidth, nHeight);
@@ -798,7 +811,7 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::onImageLoaded");
 
 
 
-void AlbumInfoDownloaderDlgImpl::addNote(const char* szNote)
+void AlbumInfoDownloaderDlgImpl::addNote(const QString& qstrNote)
 {
 LAST_STEP("AlbumInfoDownloaderDlgImpl::addNote");
     QString q (m_pDownloadsM->toPlainText());
@@ -809,7 +822,7 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::addNote");
         sprintf(a, "%02d:%02d:%02d.%03d ", t.hour(), t.minute(), t.second(), t.msec());
         q += a;
     }
-    q += szNote;
+    q += qstrNote;
     m_pDownloadsM->setText(q);
 
     QScrollBar* p (m_pDownloadsM->verticalScrollBar());
@@ -879,12 +892,12 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::reloadGui");
         {
             m_pVolumeCbB->addItem(convStr(*it));
         }
-        m_pVolumeCbB->addItem("<All>");
+        m_pVolumeCbB->addItem(tr("<All>"));
     }
 
 
     QString q1 (m_nTotalPages == m_nLastLoadedPage + 1 ? "" : "+");
-    QString s (QString("Album %1/%2%3, image %4/%5").arg(m_nCrtAlbum + 1).arg(getAlbumCount()).arg(q1).arg(m_nCrtImage + 1).arg(albumInfo.m_vpImages.size()));
+    QString s (tr("Album %1/%2%3, image %4/%5").arg(m_nCrtAlbum + 1).arg(getAlbumCount()).arg(q1).arg(m_nCrtImage + 1).arg(albumInfo.m_vpImages.size()));
     m_pResultNoL->setText(s);
 
     m_pResArtistE->setText(convStr(albumInfo.m_strArtist));
@@ -894,7 +907,7 @@ LAST_STEP("AlbumInfoDownloaderDlgImpl::reloadGui");
     {
         m_pImageL->setPixmap(0);
         m_pImageL->setText("");
-        m_pImgSizeL->setText("No image\n");
+        m_pImgSizeL->setText(tr("No image\n"));
     }
     else
     {
@@ -1115,17 +1128,17 @@ WebDwnldModel::WebDwnldModel(AlbumInfoDownloaderDlgImpl& dwnld, QTableView& grid
 }
 
 
-/*override*/ QVariant WebDwnldModel::headerData(int nSection, Qt::Orientation eOrientation, int nRole /*= Qt::DisplayRole*/) const
+/*override*/ QVariant WebDwnldModel::headerData(int nSection, Qt::Orientation eOrientation, int nRole /* = Qt::DisplayRole*/) const
 {
     if (nRole != Qt::DisplayRole) { return QVariant(); }
     if (Qt::Horizontal == eOrientation)
     {
         switch (nSection)
         {
-        case 0: return "Pos";
-        case 1: return "Title";
-        case 2: return "Artist";
-        case 3: return "Composer";
+        case 0: return tr("Pos");
+        case 1: return tr("Title");
+        case 2: return tr("Artist");
+        case 3: return tr("Composer");
         default:
             CB_ASSERT (false);
         }
