@@ -37,6 +37,8 @@
 #include  <boost/lexical_cast.hpp>
 #endif
 
+#include  "CbException.h"
+
 #ifdef ERR
 #undef ERR
 #endif
@@ -99,7 +101,7 @@ struct Note
         template<class Archive>
         void serialize(Archive& ar, const unsigned int nVersion)
         {
-            if (nVersion > 0) { throw std::runtime_error("invalid version of serialized file"); }
+            if (nVersion > 0) { CB_THROW1(CbRuntimeError, "invalid version of serialized file"); }
 
             ar & m_strDescription;
             // !!! don't care about other attributes, because after loading, a SharedData object is replaced with one from Notes::getNote(strDescr)
@@ -208,6 +210,7 @@ public:
     DECL_NOTE_INFO(xingNotBeforeAudio, ERR, XING, QT_TR_NOOP("The Xing header should be located immediately before the MPEG audio stream."), false) // e
     DECL_NOTE_INFO(incompatXing, ERR, XING, QT_TR_NOOP("The Xing header should be compatible with the MPEG audio stream, meaning that their MPEG version, layer and frequency must be equal."), false) // f
     DECL_NOTE_INFO(missingXing, WARNING, XING, QT_TR_NOOP("The MPEG audio stream uses VBR but a Xing header wasn't found. This will confuse some players, which won't be able to display the song duration or to seek."), false) // g
+    DECL_NOTE_INFO(xingFrameInCount, WARNING, XING, QT_TR_NOOP("Xing header included in audio frame count. This is probably best ignored, as most players are fine with it and the fix erases potentially important information, like gapless playing information or the table of contents."), false) // h
 
     // vbri // c
     DECL_NOTE_INFO(twoVbri, ERR, VBRI, QT_TR_NOOP("Two VBRI headers found, but a file should have at most one of them."), true) // a
@@ -323,6 +326,7 @@ public:
     DECL_NOTE_INFO(tooManyStreams, WARNING, MISC, QT_TR_NOOP("Too many streams found. Aborting processing."), false) // e
     DECL_NOTE_INFO(unsupportedFound, WARNING, MISC, QT_TR_NOOP("Unsupported stream found. It may be supported in the future if there's a real need for it."), false) // f
     DECL_NOTE_INFO(rescanningNeeded, WARNING, MISC, QT_TR_NOOP("The file was saved using the \"fast\" option. While this improves the saving speed, it may leave the notes in an inconsistent state, so you should rescan the file."), false) // g
+    DECL_NOTE_INFO(failedToRead, ERR, MISC, QT_TR_NOOP("An error occurred while reading the file, so it wasn't fully processed. This usually happens when reading from external drives or USB sticks, in which case a workaround might be to copy the files to an internal drive."), false) // h
 
     struct CompNoteByName // needed for searching
     {
@@ -354,7 +358,7 @@ private:
 template<class Archive>
 inline void Note::save(Archive& ar, const unsigned int nVersion) const
 {
-    if (nVersion > 0) { throw std::runtime_error("invalid version of serialized file"); }
+    if (nVersion > 0) { CB_THROW1(CbRuntimeError, "invalid version of serialized file"); }
 
     ar << m_pSharedData;
     ar << m_pos;
@@ -364,7 +368,7 @@ inline void Note::save(Archive& ar, const unsigned int nVersion) const
 template<class Archive>
 inline void Note::load(Archive& ar, const unsigned int nVersion)
 {
-    if (nVersion > 0) { throw std::runtime_error("invalid version of serialized file"); }
+    if (nVersion > 0) { CB_THROW1(CbRuntimeError, "invalid version of serialized file"); }
 
     SharedData* pSharedData;
     ar >> pSharedData;
@@ -412,7 +416,7 @@ private:
     template<class Archive>
     void serialize(Archive& ar, const unsigned int nVersion)
     {
-        if (nVersion > 0) { throw std::runtime_error("invalid version of serialized file"); }
+        if (nVersion > 0) { CB_THROW1(CbRuntimeError, "invalid version of serialized file"); }
 
         ar & m_vpNotes;
 
@@ -524,7 +528,7 @@ private:
     template<class Archive>
     void serialize(Archive& ar, const unsigned int nVersion)
     {
-        if (nVersion > 0) { throw std::runtime_error("invalid version of serialized file"); }
+        if (nVersion > 0) { CB_THROW1(CbRuntimeError, "invalid version of serialized file"); }
 
         ar & s;
     }
