@@ -32,7 +32,10 @@
 #include  "Helpers.h"
 #include  "Transformation.h"
 #include  "StoredSettings.h"
-
+#include  "OsFile.h"
+#include  "Translation.h"
+#include  "CommonData.h"
+#include  "Widgets.h"
 
 using namespace std;
 //using namespace pearl;
@@ -59,18 +62,34 @@ void SessionEditorDlgImpl::commonConstr() // common code for both constructors
     grayPalette.setColor(QPalette::Base, grayPalette.color(QPalette::Disabled, QPalette::Window));
     m_pBackupE->setPalette(grayPalette);
     m_pFileNameE->setPalette(grayPalette);
+
+    { // language
+        int nCrt (0);
+        const vector<string>& vstrTranslations (TranslatorHandler::getGlobalTranslator().getTranslations());
+        string strTmpTranslation (m_strTranslation); // !!! needed because on_m_pTranslationCbB_currentIndexChanged() will get triggered and change m_strTranslation
+        for (int i = 0; i < cSize(vstrTranslations); ++i)
+        {
+            m_pTranslationCbB->addItem(convStr(TranslatorHandler::getLanguageInfo(vstrTranslations[i])));
+            if (strTmpTranslation == vstrTranslations[i])
+            {
+                nCrt = i;
+            }
+        }
+        m_pTranslationCbB->setCurrentIndex(nCrt);
+        m_strTranslation = vstrTranslations[m_pTranslationCbB->currentIndex()];
+    }
 }
 
 
 // used for creating a new session;
-SessionEditorDlgImpl::SessionEditorDlgImpl(QWidget* pParent, const string& strDir, bool bFirstTime) : QDialog(pParent, getDialogWndFlags()), Ui::SessionEditorDlg(), m_strDir(strDir), m_bNew(true)
+SessionEditorDlgImpl::SessionEditorDlgImpl(QWidget* pParent, const string& strDir, bool bFirstTime, const string& strTranslation) : QDialog(pParent, getDialogWndFlags()), Ui::SessionEditorDlg(), m_strDir(strDir), m_bNew(true), m_strTranslation(strTranslation)
 {
     commonConstr();
 
     bool bAutoFileName (false);
     {
 #ifndef WIN32
-        QString qs (QDir::homePath() + "/Documents"); // OK on openSUSE, not sure how standardized it is
+        QString qs (QDir::homePath() + "/Documents"); // OK on openSUSE, not sure how standardized it is //ttt0 this is localized, so not OK; look at Qt
 #else
         QSettings settings (QSettings::UserScope, "Microsoft", "Windows");
         settings.beginGroup("CurrentVersion/Explorer/Shell Folders");
@@ -78,7 +97,8 @@ SessionEditorDlgImpl::SessionEditorDlgImpl(QWidget* pParent, const string& strDi
 #endif
         if (QFileInfo(qs).isDir())
         {
-            qs += "/MP3Diags.ini";
+            qs += "/MP3Diags";
+            qs += SESS_EXT;
             if (!QDir().exists(qs))
             {
                 m_pFileNameE->setText(toNativeSeparators(qs));
@@ -88,21 +108,21 @@ SessionEditorDlgImpl::SessionEditorDlgImpl(QWidget* pParent, const string& strDi
     }
 
     //setWindowTitle("MP3 Diags - Create a new session or load an existing one");
-    setWindowTitle("MP3 Diags - Create new session");
+    setWindowTitle();
     m_pDontCreateBackupRB->setChecked(true);
     m_pScanAtStartupCkB->setChecked(true);
 
     m_pFileNameE->setToolTip(bAutoFileName ?
-        "This is the name of the \"settings file\"\n\n"
+        tr("This is the name of the \"settings file\"\n\n"
         "It is supposed to be a file that doesn't already exist. You don't need to set it up. MP3 Diags\n"
         "will store its settings in this file.\n\n"
         "The name was generated automatically. If you want to choose a different name, simply click on\n"
-        "the button at the right to change it." :
+        "the button at the right to change it.", "this is a multiline tooltip") :
 
-        "Here you need to specify the name of a \"settings file\"\n\n"
+        tr("Here you need to specify the name of a \"settings file\"\n\n"
         "This is supposed to be a file that doesn't already exist. You don't need to set it up. MP3 Diags\n"
         "will store its settings in this file.\n\n"
-        "To change it, simply click on the button at the right to choose the name of the settings file.");
+        "To change it, simply click on the button at the right to choose the name of the settings file.", "this is a multiline tooltip"));
 
     if (!bFirstTime)
     {
@@ -113,22 +133,29 @@ SessionEditorDlgImpl::SessionEditorDlgImpl(QWidget* pParent, const string& strDi
 
 
 // used for editing an existing session;
-SessionEditorDlgImpl::SessionEditorDlgImpl(QWidget* pParent, const string& strIniFile) : QDialog(pParent, getDialogWndFlags()), Ui::SessionEditorDlg(), m_bNew(false)
+SessionEditorDlgImpl::SessionEditorDlgImpl(QWidget* pParent, const string& strSessFile) : QDialog(pParent, getDialogWndFlags()), Ui::SessionEditorDlg(), m_bNew(false)
 {
+    SessionSettings st (strSessFile);
+    {
+        CommonData commonData(st, 0, 0, 0, 0, 0, 0, 0, 0, 0, false);
+        st.loadMiscConfigSettings(&commonData, SessionSettings::DONT_INIT_GUI);
+        m_strTranslation = commonData.m_strTranslation;
+    }
+
     commonConstr();
 
-    setWindowTitle("MP3 Diags - Edit session");
+    setWindowTitle();
     m_pFileNameE->setReadOnly(true);
-    m_pFileNameE->setText(toNativeSeparators(convStr(strIniFile)));
+    m_pFileNameE->setText(toNativeSeparators(convStr(strSessFile)));
     m_pFileNameB->hide();
     m_pOpenLastCkB->hide();
     //m_pLoadB->hide();
     m_pOpenSessionsB->hide();
 
-    m_strIniFile = strIniFile;
-    CB_ASSERT (!m_strIniFile.empty());
+    m_strSessFile = strSessFile;
+    CB_ASSERT (!m_strSessFile.empty());
 
-    SessionSettings st (m_strIniFile);
+    //SessionSettings st (m_strSessFile);
     vector<string> vstrCheckedDirs, vstrUncheckedDirs;
     st.loadDirs(vstrCheckedDirs, vstrUncheckedDirs);
 
@@ -163,7 +190,10 @@ void SessionEditorDlgImpl::onShow()
 }
 
 
-
+void SessionEditorDlgImpl::setWindowTitle()
+{
+    QDialog::setWindowTitle(m_bNew ? tr("MP3 Diags - Create new session") : tr("MP3 Diags - Edit session"));
+}
 
 // returns the name of an INI file for OK and an empty string for Cancel; returns "*" to just go to the sessions dialog;
 string SessionEditorDlgImpl::run()
@@ -176,12 +206,12 @@ string SessionEditorDlgImpl::run()
     if (QDialog::Accepted != exec()) { return ""; }
 
     gs.saveSessionEdtSize(width(), height());
+    m_strTranslation = TranslatorHandler::getGlobalTranslator().getTranslations()[m_pTranslationCbB->currentIndex()];
 
-    return m_strIniFile;
+    return m_strSessFile;
 }
 
 
-
 void SessionEditorDlgImpl::on_m_pOkB_clicked()
 {
     m_bOpenLastSession = m_pOpenLastCkB->isChecked();
@@ -191,12 +221,12 @@ void SessionEditorDlgImpl::on_m_pOkB_clicked()
     if (m_bNew)
     {
         QString qstrFile (fromNativeSeparators(m_pFileNameE->text()));
-        if (!qstrFile.isEmpty() && !qstrFile.endsWith(".ini")) { qstrFile += ".ini"; m_pFileNameE->setText(toNativeSeparators(qstrFile)); }
-        //m_strIniFile = convStr(QFileInfo(qstrFile).canonicalFilePath());
-        m_strIniFile = convStr(qstrFile);
-        if (m_strIniFile.empty())
+        if (!qstrFile.isEmpty() && !qstrFile.endsWith(SESS_EXT)) { qstrFile += SESS_EXT; m_pFileNameE->setText(toNativeSeparators(qstrFile)); }
+        //m_strSessFile = convStr(QFileInfo(qstrFile).canonicalFilePath());
+        m_strSessFile = convStr(qstrFile);
+        if (m_strSessFile.empty())
         {
-            QMessageBox::critical(this, "Error", "You need to specify the name of the settings file.\n\nThis is supposed to be a file that doesn't already exist. You don't need to set it up, but just to pick a name for it. MP3 Diags will store its settings in this file.");
+            showCritical(this, tr("Error"), tr("You need to specify the name of the settings file.\n\nThis is supposed to be a file that doesn't already exist. You don't need to set it up, but just to pick a name for it. MP3 Diags will store its settings in this file."));
             on_m_pFileNameB_clicked();
             return;
         }
@@ -206,7 +236,7 @@ void SessionEditorDlgImpl::on_m_pOkB_clicked()
 
     if (vstrCheckedDirs.empty())
     {
-        QMessageBox::critical(this, "Error", "You need to select at least a directory to be included in the session.");
+        showCritical(this, tr("Error"), tr("You need to select at least a directory to be included in the session."));
         return;
     }
 
@@ -215,7 +245,7 @@ void SessionEditorDlgImpl::on_m_pOkB_clicked()
         QString s (fromNativeSeparators(m_pBackupE->text()));
         if (s.isEmpty() || !QFileInfo(s).isDir())
         {
-            QMessageBox::critical(this, "Error", "If you want to create backups, you must select an existing directory to store them.");
+            showCritical(this, tr("Error"), tr("If you want to create backups, you must select an existing directory to store them."));
             return;
         }
     }
@@ -225,10 +255,10 @@ void SessionEditorDlgImpl::on_m_pOkB_clicked()
     {
         if (m_bNew)
         {
-            removeSession(m_strIniFile);
+            removeSession(m_strSessFile);
         }
 
-        SessionSettings st (m_strIniFile);
+        SessionSettings st (m_strSessFile);
 
         TransfConfig tc;
         if (!m_bNew)
@@ -252,12 +282,20 @@ void SessionEditorDlgImpl::on_m_pOkB_clicked()
 
         st.saveScanAtStartup(m_pScanAtStartupCkB->isChecked());
 
+        {
+            CommonData commonData(st, 0, 0, 0, 0, 0, 0, 0, 0, 0, false);
+            st.loadMiscConfigSettings(&commonData, SessionSettings::DONT_INIT_GUI);
+            commonData.m_strTranslation = m_strTranslation;
+            st.saveMiscConfigSettings(&commonData);
+        }
+
+
         if (!st.sync())
         {
-            QMessageBox::critical(this, "Error", "Failed to write to file " + m_pFileNameE->text());
+            showCritical(this, tr("Error"), tr("Failed to write to file %1").arg(m_pFileNameE->text()));
             if (m_bNew)
             {
-                removeSession(m_strIniFile);
+                removeSession(m_strSessFile);
             }
             return;
         }
@@ -279,7 +317,7 @@ void SessionEditorDlgImpl::on_m_pBackupB_clicked()
     {
         s = QDir::homePath();
     }
-    QFileDialog dlg (this, "Select folder", s, "All files (*)");
+    QFileDialog dlg (this, tr("Select folder"), s, tr("All files (*)"));
     //dlg.setAcceptMode(QFileDialog::AcceptSave);
 
     dlg.setFileMode(QFileDialog::Directory);
@@ -315,7 +353,7 @@ void SessionEditorDlgImpl::on_m_pFileNameB_clicked()
             s = convStr(m_strDir);
         }
     }
-    QFileDialog dlg (this, "Enter configuration file", s, "INI files (*.ini)");
+    QFileDialog dlg (this, tr("Enter configuration file"), s, tr("MP3 Diags session files (*%1)").arg(SESS_EXT));
     dlg.setAcceptMode(QFileDialog::AcceptSave);
 
     //dlg.setFileMode(QFileDialog::Directory);
@@ -326,40 +364,68 @@ void SessionEditorDlgImpl::on_m_pFileNameB_clicked()
 
     s = fileNames.first();
 
-    if (!s.endsWith(".ini")) { s += ".ini"; }
+    if (!s.endsWith(SESS_EXT)) { s += SESS_EXT; }
 
     m_pFileNameE->setText(toNativeSeparators(s));
 }
 
 
-/*static*/ string SessionEditorDlgImpl::getDataFileName(const string& strIniName)
+/*static*/ string SessionEditorDlgImpl::getDataFileName(const string& strSessFile)
 {
-    CB_ASSERT (endsWith(strIniName, ".ini"));
-    return strIniName.substr(0, strIniName.size() - 4) + ".dat";
+    CB_ASSERT (endsWith(strSessFile, SESS_EXT));
+    return strSessFile.substr(0, strSessFile.size() - SESS_EXT_LEN) + ".dat";
 }
 
-/*static*/ string SessionEditorDlgImpl::getLogFileName(const string& strIniName)
+/*static*/ string SessionEditorDlgImpl::getLogFileName(const string& strSessFile)
 {
-    CB_ASSERT (endsWith(strIniName, ".ini"));
-    return strIniName.substr(0, strIniName.size() - 4) + ".transf_log.txt";
+    CB_ASSERT (endsWith(strSessFile, SESS_EXT));
+    return strSessFile.substr(0, strSessFile.size() - SESS_EXT_LEN) + ".transf_log.txt";
+}
+
+/*static*/ string SessionEditorDlgImpl::getBaseName(const string& strSessFile)
+{
+    CB_ASSERT (endsWith(strSessFile, SESS_EXT));
+    return strSessFile.substr(0, strSessFile.size() - SESS_EXT_LEN);
+}
+
+/*static*/ string SessionEditorDlgImpl::getTitleName(const string& strSessFile)
+{
+    CB_ASSERT (endsWith(strSessFile, SESS_EXT));
+
+    string::size_type n (strSessFile.rfind(getPathSep()));
+    return strSessFile.substr(n + 1, strSessFile.size() - n - SESS_EXT_LEN - 1);
 }
 
 
-/*static*/ void SessionEditorDlgImpl::removeSession(const string& strIniName) // removes INI, DAT, and LOG
+ // removes all files associated with a session: .ini, .mp3ds, .log, .dat, _trace.txt, _step1.txt, _step2.txt
+/*static*/ void SessionEditorDlgImpl::removeSession(const string& strSessFile)
 {
-    QFile::remove(convStr(strIniName)); // ttt2 perhaps check ...
-    QFile::remove(convStr(getDataFileName(strIniName)));
-    QFile::remove(convStr(getLogFileName(strIniName)));
+    eraseFiles(strSessFile.substr(0, strSessFile.size() - SESS_EXT_LEN));
 }
 
 
+/*static*/ const char* const SessionEditorDlgImpl::SESS_EXT (".ini"); //ttt0 perhaps switch to .mp3ds (keep in mind that there may be many folders with .ini in them now); the point is to be able to double-click on a .mp3ds file
+/*static*/ int SessionEditorDlgImpl::SESS_EXT_LEN (strlen(SessionEditorDlgImpl::SESS_EXT));
+
+
 void SessionEditorDlgImpl::on_m_pOpenSessionsB_clicked()
 {
-    m_strIniFile = "*";
+    m_strSessFile = "*";
     accept();
 }
 
 
+void SessionEditorDlgImpl::on_m_pTranslationCbB_currentIndexChanged(int)
+{
+    const vector<string>& vstrTranslations (TranslatorHandler::getGlobalTranslator().getTranslations());
+    m_strTranslation = vstrTranslations[m_pTranslationCbB->currentIndex()];
+
+    TranslatorHandler::getGlobalTranslator().setTranslation(m_strTranslation);
+    retranslateUi(this);
+    setWindowTitle();
+}
+
+
 void SessionEditorDlgImpl::onHelp()
 {
     openHelp("110_first_run.html"); //ttt2 not quite right, since there are 2 "modes"
